@@ -852,7 +852,7 @@ PERL_STATIC_INLINE UV
 Perl_SvUV_nomg(pTHX_ SV *sv) {
     PERL_ARGS_ASSERT_SVUV_NOMG;
 
-    if (SvIOK_nog(sv))
+    if (SvUOK(sv))
         return SvUVX(sv);
     return sv_2uv_flags(sv, 0);
 }
@@ -861,7 +861,7 @@ PERL_STATIC_INLINE NV
 Perl_SvNV_nomg(pTHX_ SV *sv) {
     PERL_ARGS_ASSERT_SVNV_NOMG;
 
-    if (SvNOK_nog(sv))
+    if (SvNOK(sv))
         return SvNVX(sv);
     return sv_2nv_flags(sv, 0);
 }
@@ -994,7 +994,9 @@ Perl_sv_setpv_freshbuf(pTHX_ SV *const sv)
     assert(SvPVX(sv));
     SvCUR_set(sv, 0);
     *(SvEND(sv))= '\0';
-    (void)SvPOK_only_UTF8(sv);
+    (void)SvPOK_only_UTF8(sv);  /* UTF-8 flag will be 0; This is used instead
+                                   of 'SvPOK_only' because the other sv_setpv
+                                   functions use it */
     SvTAINT(sv);
     return SvPVX(sv);
 }
